@@ -85,7 +85,7 @@ def _writeParamField(componentOption, NewParamValueDictionary):
 	dbPW = getWebConfigDBPassword()
 	dbUserName = getWebConfigDBUsername()
 	dbName = getWebConfigDBName()	
-	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
 	parmString = ""
 	for parm in NewParamValueDictionary:
@@ -93,7 +93,7 @@ def _writeParamField(componentOption, NewParamValueDictionary):
 		
 	sql = "UPDATE jos_components set params = %s WHERE `option` = %s"
 	data = (parmString, componentOption)
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 
 
 def _buildDictionary(componentOption):
@@ -110,13 +110,12 @@ def _buildDictionary(componentOption):
 	dbPW = getWebConfigDBPassword()
 	dbUserName = getWebConfigDBUsername()
 	dbName = getWebConfigDBName()	
-	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	
 	# look up parm string and parse it on newline, for each line, parse it further based on *first* '='
 	sql = "SELECT `params` from jos_components WHERE `option`=%s"
 	data = (componentOption)
-	paramsString = db.execSelectQueryScalar(sql, data)
-	
+	paramsString = db.query_selectscalar(sql, data)
 	parms = paramsString.split("\n")
 	
 	parmsDict = {}
@@ -175,11 +174,11 @@ def setPluginEnabled(pluginFolder, pluginElement, enable):
 	dbPW = getWebConfigDBPassword()
 	dbUserName = getWebConfigDBUsername()
 	dbName = getWebConfigDBName()	
-	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 		
 	sql = "UPDATE jos_plugins set published = %s WHERE `folder` = %s AND `element` = %s"
 	data = (enable, pluginFolder, pluginElement)
-	db.execQuery(sql, data)	
+	db.query_rowcount(sql, data)	
 
 
 def getHubSiteConfig(hubname, sectionName, valueName):
